==> gWidgetstcltk_0.0-7.tar.gz: gWidgetstcltk/R/gedit.R <==
## class defined in aaaClasses for inheritance
## constructor
setClass("gEdittcltk",
         representation = representation("gComponenttcltk",
           coercewith="NULLorFunction"),
         contains="gComponenttcltk",
         prototype=prototype(new("gComponenttcltk"))
         )


setMethod(".gedit",
          signature(toolkit="guiWidgetsToolkittcltk"),
          function(toolkit,
                   text="", width=25,
                   coerce.with = NULL, 
                   handler=NULL, action=NULL,
                   container=NULL,
                   ...
                   ) {

           force(toolkit)
            
            if(is(container,"logical") && container)
              container = gwindow()
            if(!is(container,"guiWidget")) {
              warning("Container is not correct. No NULL containers possible\n" )
              return()
            }


           if (is.null(text)) text<-""

            ## check that coerce.with is a function
            if(is.null(coerce.with) || is.function(coerce.with)) {
              ## okay
            } else {
              if(is.character(coerce.with)) {
                coerce.with = get(coerce.with)
              }
            }

           tt = getBlock(container)
           gp = tkframe(tt)

           entryValue = tclVar(text)
           entry = tkentry(gp,width=as.character(width),
             textvariable = entryValue)
           tkgrid(entry)
           
            obj = new("gEdittcltk",block=gp, widget=entry,
              toolkit=toolkit,ID=getNewID(),coercewith=coerce.with)
           tag(obj,"tclVar") <- entryValue
           

           ## Drag and drop
           ## addDropSource(obj)
           ## addDropTarget(obj)
           
           ## add to container@widget@block
           add(container, obj,...)
           
            if (!is.null(handler)) {
              id = addhandlerchanged(obj,handler,action)
            }
           
           invisible(obj)
            
            
          })

## methods
setMethod(".svalue",
          signature(toolkit="guiWidgetsToolkittcltk",obj="gEdittcltk"),
          function(obj, toolkit, index=NULL, drop=NULL, ...) {

            val = tclvalue(tag(obj,"tclVar"))

            coercewith = obj@coercewith
            if(!is.null(coercewith))
              val = do.call(coercewith, list(val))

            return(val)
          })

## svalue<-
setReplaceMethod(".svalue",
                 signature(toolkit="guiWidgetsToolkittcltk",obj="gEdittcltk"),
                 function(obj, toolkit, index=NULL, ..., value) {
                   tclvalue(tag(obj, "tclVar")) <- value
                   return(obj)
          })


## left bracket implement completion
setMethod(".leftBracket",
          signature(toolkit="guiWidgetsToolkittcltk",x="gEdittcltk"),
          function(x, toolkit, i, j, ..., drop=TRUE) {
            cat("gedit: completion is not implemented\n")
          })
            
setMethod("[",
          signature(x="gEdittcltk"),
          function(x, i, j, ..., drop=TRUE) {
            cat("gedit: completion is not implemented\n")
          })

setReplaceMethod(".leftBracket",
          signature(toolkit="guiWidgetsToolkittcltk",x="gEdittcltk"),
          function(x, toolkit, i, j, ..., value) {
            cat("gedit: completion is not implemented\n")
            return(x)
          })

setReplaceMethod("[",
                 signature(x="gEdittcltk"),
                 function(x, i, j,..., value) {
                   .leftBracket(x, x@toolkit, i, j, ...) <- value
                   return(x)
                 })


setReplaceMethod(".size", 
                 signature(toolkit="guiWidgetsToolkittcltk",obj="gEdittcltk"),
                 function(obj, toolkit, ..., value) {
                   if(is.numeric(value))
                     tkconfigure(obj@widget,width=floor(value[1]/5)) 
                                        # convert pixels to chars
                   else
                     cat("size needs a numeric vector c(width,...)\n")
                   return(obj)
                 })



##################################################
## handlers

## changed is called after a commit
## keystroke is called when widget display changes


setMethod(".addhandlerchanged",
          signature(toolkit="guiWidgetsToolkittcltk",obj="gEdittcltk"),
          function(obj, toolkit, handler, action=NULL, ...) {
            .addHandler(obj, toolkit, signal="<Return>", handler, action)
          })

setMethod(".addhandlerkeystroke",
          signature(toolkit="guiWidgetsToolkittcltk",obj="gEdittcltk"),
          function(obj,toolkit, handler=NULL, action=NULL,...) {
            .addHandler(obj, toolkit, signal="<Key>", handler, action)
          })

==> gWidgetstcltk_0.0-9.tar.gz: gWidgetstcltk/R/gedit.R <==
## class defined in aaaClasses for inheritance
## constructor
setClass("gEdittcltk",
         representation = representation("gComponenttcltk",
           coercewith="NULLorFunction"),
         contains="gComponenttcltk",
         prototype=prototype(new("gComponenttcltk"))
         )


setMethod(".gedit",
          signature(toolkit="guiWidgetsToolkittcltk"),
          function(toolkit,
                   text="", width=25,
                   coerce.with = NULL, 
                   handler=NULL, action=NULL,
                   container=NULL,
                   ...
                   ) {

           force(toolkit)
            
            if(is(container,"logical") && container)
              container = gwindow()
            if(!is(container,"guiWidget")) {
              warning("Container is not correct. No NULL containers possible\n" )
              return()
            }


           if (is.null(text)) text<-""

            ## check that coerce.with is a function
            if(is.null(coerce.with) || is.function(coerce.with)) {
              ## okay
            } else {
              if(is.character(coerce.with)) {
                coerce.with = get(coerce.with)
              }
            }

           tt = getBlock(container)
           gp = ttkframe(tt)

           entryValue = tclVar(text)
           entry = ttkentry(gp,width=as.character(width),
             textvariable = entryValue)
           tkgrid(entry)
           
            obj = new("gEdittcltk",block=gp, widget=entry,
              toolkit=toolkit,ID=getNewID(),e = new.env(),
              coercewith=coerce.with)
           tag(obj,"tclVar") <- entryValue
           

           ## Drag and drop
           ## addDropSource(obj)
           ## addDropTarget(obj)
           
           ## add to container@widget@block
           add(container, obj,...)
           
            if (!is.null(handler)) {
              id = addhandlerchanged(obj,handler,action)
            }
           
           invisible(obj)
            
            
          })

## methods
setMethod(".svalue",
          signature(toolkit="guiWidgetsToolkittcltk",obj="gEdittcltk"),
          function(obj, toolkit, index=NULL, drop=NULL, ...) {

            val = tclvalue(tag(obj,"tclVar"))

            coercewith = obj@coercewith
            if(!is.null(coercewith))
              val = do.call(coercewith, list(val))

            return(val)
          })

## svalue<-
setReplaceMethod(".svalue",
                 signature(toolkit="guiWidgetsToolkittcltk",obj="gEdittcltk"),
                 function(obj, toolkit, index=NULL, ..., value) {
                   tclvalue(tag(obj, "tclVar")) <- value
                   return(obj)
          })


## left bracket implement completion
setMethod(".leftBracket",
          signature(toolkit="guiWidgetsToolkittcltk",x="gEdittcltk"),
          function(x, toolkit, i, j, ..., drop=TRUE) {
            gwCat(gettext("gedit: completion is not implemented\n"))
          })
            
setMethod("[",
          signature(x="gEdittcltk"),
          function(x, i, j, ..., drop=TRUE) {
            gwCat(gettext("gedit: completion is not implemented\n"))
          })

setReplaceMethod(".leftBracket",
          signature(toolkit="guiWidgetsToolkittcltk",x="gEdittcltk"),
          function(x, toolkit, i, j, ..., value) {
            gwCat(gettext("gedit: completion is not implemented\n"))
            return(x)
          })

setReplaceMethod("[",
                 signature(x="gEdittcltk"),
                 function(x, i, j,..., value) {
                   .leftBracket(x, x@toolkit, i, j, ...) <- value
                   return(x)
                 })


setReplaceMethod(".size", 
                 signature(toolkit="guiWidgetsToolkittcltk",obj="gEdittcltk"),
                 function(obj, toolkit, ..., value) {
                   if(is.numeric(value))
                     tkconfigure(obj@widget,width=floor(value[1]/5)) 
                                        # convert pixels to chars
                   else
                     cat(gettext("size needs a numeric vector c(width,...)\n"))
                   return(obj)
                 })



##################################################
## handlers

## changed is called after a commit
## keystroke is called when widget display changes


setMethod(".addhandlerchanged",
          signature(toolkit="guiWidgetsToolkittcltk",obj="gEdittcltk"),
          function(obj, toolkit, handler, action=NULL, ...) {
            .addHandler(obj, toolkit, signal="<Return>", handler, action)
          })

setMethod(".addhandlerkeystroke",
          signature(toolkit="guiWidgetsToolkittcltk",obj="gEdittcltk"),
          function(obj,toolkit, handler=NULL, action=NULL,...) {
            .addHandler(obj, toolkit, signal="<Key>", handler, action)
          })
